##  Conduct a Risk Remediation Analysis
Depending on your organizational need and situation, you can accept and monitor risks without immediate action, establish a risk dispensation program to temporarily accept specific risks, or actively plan to upgrade or remove outdated technologies from the environment. The ultimate goal is to ensure that all risks in the portfolio are either accepted or have a remediation plan in place, leaving no unaddressed or unplanned risks.
Go through each unaddressed risk based on their priority, and task the application owner with developing remediation plans for each risk. For instance, the plan could include upgrading to a new, supported version of the outdated IT component, or swapping it with a different IT component. Alternatively, it might involve migrating to an entirely different application. The action plan depends on the application owner's assessment of what the organization needs to support its business capabilities. Typically, Project Management Office personnel will also be involved in planning, scheduling, and approving these remediation efforts.
